diff --git a/spring-data-neo4j-roo/pom.xml b/spring-data-neo4j-roo/pom.xml
index 2ee93c2fe..78cab9a5e 100644
--- a/spring-data-neo4j-roo/pom.xml
+++ b/spring-data-neo4j-roo/pom.xml
@@ -11,7 +11,7 @@
jar
Spring Data Neo4J Roo Support
- 1.6.10.RELEASE
+ 1.6.11.BUILD-SNAPSHOT
diff --git a/spring-data-neo4j/src/main/java/org/springframework/data/graph/neo4j/template/Neo4jTemplate.java b/spring-data-neo4j/src/main/java/org/springframework/data/graph/neo4j/template/Neo4jTemplate.java
index 85a961771..f6e90caa7 100644
--- a/spring-data-neo4j/src/main/java/org/springframework/data/graph/neo4j/template/Neo4jTemplate.java
+++ b/spring-data-neo4j/src/main/java/org/springframework/data/graph/neo4j/template/Neo4jTemplate.java
@@ -30,7 +30,7 @@ import java.util.Map;
public class Neo4jTemplate implements Neo4jOperations {
- private final boolean useExplictTransactions;
+ private final boolean useExplicitTransactions;
private final GraphDatabaseService graphDatabaseService;
@@ -51,7 +51,7 @@ public class Neo4jTemplate implements Neo4jOperations {
* @param graphDatabaseService the neo4j graph database
* @return a Neo4jTemplate instance
*/
- public static Neo4jTemplate templateWithExplictTransactions(GraphDatabaseService graphDatabaseService) {
+ public static Neo4jTemplate templateWithExplicitTransactions(GraphDatabaseService graphDatabaseService) {
return new Neo4jTemplate(graphDatabaseService,true);
}
@@ -66,13 +66,13 @@ public class Neo4jTemplate implements Neo4jOperations {
/**
* @param graphDatabaseService the neo4j graph database
* @param useExplictTransactions if set the template only participates in outside transactions,
* no internal implicit transactions are started
* @return a Neo4jTemplate instance
*/
- public Neo4jTemplate(final GraphDatabaseService graphDatabaseService, boolean useExplictTransactions) {
+ public Neo4jTemplate(final GraphDatabaseService graphDatabaseService, boolean useExplicitTransactions) {
notNull(graphDatabaseService, "graphDatabaseService");
- this.useExplictTransactions = useExplictTransactions;
+ this.useExplicitTransactions = useExplicitTransactions;
this.graphDatabaseService = graphDatabaseService;
index = this.graphDatabaseService.index();
}
@@ -82,7 +82,7 @@ public class Neo4jTemplate implements Neo4jOperations {
}
private Transaction beginTx() {
- if (useExplictTransactions) {
+ if (useExplicitTransactions) {
return new NullTransaction();
}
return graphDatabaseService.beginTx();
@@ -66,13 +66,13 @@ public class Neo4jTemplate implements Neo4jOperations {
/**
* @param graphDatabaseService the neo4j graph database
- * @param useExplictTransactions if set the template only participates in outside transactions,
+ * @param useExplicitTransactions if set the template only participates in outside transactions,
* no internal implicit transactions are started
* @return a Neo4jTemplate instance